@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11715 2019-09-18 14:34:08Z Lavender $
+# $Id: __init__.py 11702 2019-09-10 19:28:08Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-09-18 23:34:08 +0900 (週三, 18 九月 2019) $
-# $Revision: 11715 $
+# $Date: 2019-09-11 03:28:08 +0800 (週三, 11 九月 2019) $
+# $Revision: 11702 $
 
 import os
 import sys
@@ -504,16 +504,7 @@ def attachSettings(settingsDict, enablePaypal=False):
             raise KeyError("You should also set '%s' value." % str(unsettings))
     
     #=========================================================================
-    
-    #=========================================================================
-    # oscar ckeditor dashboard
-    DEFAULT_CKEDITOR_SETTINGS = {
-        'IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR': True,
-        'IUNO_SHOP_CONTENT_BLOCK_CKEDITOR': True,
-        'IUNO_SHOP_PAGE_CKEDITOR': True,
-    }
-    update(settingsDict, DEFAULT_CKEDITOR_SETTINGS)
-    
+
     
 
 def attachShopURLs(settings, urlpatterns):
